@@ -10,16 +10,17 @@
     :copyright: (c) 2015 by Ryan Gibson, see AUTHORS.md for more details.
     :license: MIT License, see LICENSE.md for more details.
 """
+from PIL import Image
+from time import time
+from typing import cast, Tuple, Iterable
 import logging
 import os
-from time import time
 
-from PIL import Image
 
 log = logging.getLogger(__name__)
 
 
-def show_lsb(image_path, n):
+def show_lsb(image_path: str, n: int) -> None:
     """Shows the n least significant bits of image"""
     if image_path is None:
         raise ValueError("StegDetect requires an input image file path")
@@ -31,12 +32,18 @@ def show_lsb(image_path, n):
     # using bitwise AND on an integer
     mask = (1 << n) - 1
 
+    image_data = cast(Iterable[Tuple[int, int, int]], image.getdata())
     color_data = [
         (255 * ((rgb[0] & mask) + (rgb[1] & mask) + (rgb[2] & mask)) // (3 * mask),) * 3
-        for rgb in image.getdata()
+        for rgb in image_data
     ]
 
-    image.putdata(color_data)
+    # TODO: image.putdata() appears to have buggy typing?
+    image.putdata(color_data)  # type: ignore
     log.debug(f"Runtime: {time() - start:.2f}s")
     file_name, file_extension = os.path.splitext(image_path)
     image.save(file_name + "_{}LSBs".format(n) + file_extension)
+
+
+if __name__ == "__main__":
+    show_lsb("/home/ryan/Desktop/featured-improve-test-taking.png", 1)
